@@ -10,7 +10,7 @@ import tempfile
 
 app = typer.Typer(help="Package manager for text adventure games.", name="mait")
 
-HOST = '54.159.187.169'
+HOST = 'temperatecafe.com'
 PORT = 6440  # TCP is 8081, no longer functional.
 
 SERVER = (HOST, PORT)
@@ -226,4 +226,4 @@ def upload(path: str):
 
 
 if __name__ == "__main__":
-    app()
\ No newline at end of file
+    app()
